/*
MagicSearchSource.java
Copyright (C) 2010  Belledonne Communications, Grenoble, France

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package org.linphone.core;

import androidx.annotation.Nullable;
import androidx.annotation.NonNull;

/**
* Enum describing the search categories for Magic Search. <br/>
* <br/>
*/
public enum MagicSearchSource {
    /**
    * Search in all sources. <br/>
    * <br/>
    */
    All(-1),

    /**
    * no Source specified. <br/>
    * <br/>
    * If requested in search, the list should be empty <br/>
    */
    None(0),

    /**
    * Search in friends only. <br/>
    * <br/>
    */
    Friends(1<<0),

    /**
    * Search in Call Logs. <br/>
    * <br/>
    */
    CallLogs(1<<1),

    /**
    * Search in LDAP servers. <br/>
    * <br/>
    */
    LdapServers(1<<2),

    /**
    * Search in Chat rooms participants. <br/>
    * <br/>
    */
    ChatRooms(1<<3),

    /**
    * Search from request : it is usually an address built from the request. <br/>
    * <br/>
    */
    Request(1<<4);

    protected final int mValue;

    private MagicSearchSource (int value) {
        mValue = value;
    }

    static public MagicSearchSource fromInt(int value) throws RuntimeException {
        switch(value) {
        case -1: return All;
        case 0: return None;
        case 1<<0: return Friends;
        case 1<<1: return CallLogs;
        case 1<<2: return LdapServers;
        case 1<<3: return ChatRooms;
        case 1<<4: return Request;
        default:
            throw new RuntimeException("Unhandled enum value " + value + " for MagicSearchSource");
        }
    }

    public int toInt() {
        return mValue;
    }
}
